"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.default = void 0;
class RenderResult {
    constructor(response){
        this._response = response;
    }
    toUnchunkedString() {
        if (typeof this._response !== 'string') {
            throw new Error('invariant: dynamic responses cannot be unchunked. This is a bug in Next.js');
        }
        return this._response;
    }
    async pipe(res) {
        if (typeof this._response === 'string') {
            throw new Error('invariant: static responses cannot be piped. This is a bug in Next.js');
        }
        const maybeFlush = typeof res.flush === 'function' ? ()=>res.flush()
         : ()=>{
        };
        await this._response.forEach((chunk)=>{
            res.write(chunk);
            maybeFlush();
        });
        res.end();
    }
    isDynamic() {
        return typeof this._response !== 'string';
    }
    static fromStatic(value) {
        return new RenderResult(value);
    }
}
RenderResult.empty = RenderResult.fromStatic('');
exports.default = RenderResult;

//# sourceMappingURL=render-result.js.map